docs.rs failed to build issundb-vector-0.1.0-alpha.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
issundb-vector
Vector indexing and search for IssunDB, an embedded graph database written in Rust.
This crate owns the vector index abstraction, vector metadata, vector storage integration, and the vector search APIs.
It is an internal crate; applications should depend on the issundb facade instead.
License
MIT or Apache-2.0.